@@ -4,6 +4,7 @@
  * Proprietary and confidential
  * Written by Jonathan Favian Urzola Maldonado <jonathan@artd.com.co>, 2023
 """
+
 from django.core.management.base import BaseCommand
 
 from artd_location.data.regions import REGIONS
@@ -22,7 +23,7 @@ class Command(BaseCommand):
                     name=region[1],
                     country=country,
                 )
-                print(f"{region[1]} was created")
+                self.stdout.write(self.style.SUCCESS(f"{region[1]} was created"))
             else:
                 region_obj = Region.objects.get(
                     id=region[0],
@@ -30,4 +31,4 @@ class Command(BaseCommand):
                 region_obj.name = region[1]
                 region_obj.country = country
                 region_obj.save()
-                print(f"{region[1]} was updated")
+                self.stdout.write(self.style.WARNING(f"{region[1]} was updated"))
